Class Files.ListFiles
- java.lang.Object
-
- com.google.gerrit.server.restapi.change.Files.ListFiles
-
- All Implemented Interfaces:
ETagView<RevisionResource>,RestReadView<RevisionResource>,RestView<RevisionResource>
- Enclosing class:
- Files
public static final class Files.ListFiles extends Object implements ETagView<RevisionResource>
-
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description Response<?>apply(RevisionResource resource)Process the view operation by reading from the resource.StringgetETag(RevisionResource resource)Files.ListFilessetBase(String base)Files.ListFilessetParent(int parentNum)Files.ListFilessetQuery(String query)Files.ListFilessetReviewed(boolean r)
-
-
-
Method Detail
-
setReviewed
public Files.ListFiles setReviewed(boolean r)
-
apply
public Response<?> apply(RevisionResource resource) throws RestApiException, org.eclipse.jgit.errors.RepositoryNotFoundException, IOException, PatchListNotAvailableException, PermissionBackendException
Description copied from interface:RestReadViewProcess the view operation by reading from the resource.The value of the returned response is automatically converted to JSON unless it is a
BinaryResult.The returned response defines the status code that is returned to the client. For RestReadViews this is usually
200 OK, but other 2XX or 3XX status codes are also possible (e.g.Response.Redirectcan be returned for302 Found).Throwing a subclass of
RestApiExceptionresults in a 4XX response to the client. For any other exception the client will get a500 Internal Server Errorresponse.- Specified by:
applyin interfaceRestReadView<RevisionResource>- Parameters:
resource- resource to read- Returns:
- response to return to the client
- Throws:
AuthException- the caller is not permitted to access this view.BadRequestException- the request was incorrectly specified and cannot be handled by this view.ResourceConflictException- the resource state does not permit this view to make the changes at this time.RestApiExceptionorg.eclipse.jgit.errors.RepositoryNotFoundExceptionIOExceptionPatchListNotAvailableExceptionPermissionBackendException
-
setQuery
public Files.ListFiles setQuery(String query)
-
setBase
public Files.ListFiles setBase(String base)
-
setParent
public Files.ListFiles setParent(int parentNum)
-
getETag
public String getETag(RevisionResource resource)
- Specified by:
getETagin interfaceETagView<RevisionResource>
-
-